import { Component, Event, h, Listen, Prop } from '@stencil/core';
import { ControlInfoValue } from '../../utils/utils';
export class K2btEnhancedcombo {
    constructor() {
        this.value = null;
        this.includesearch = true;
        this.includeemptyitem = true;
        this.emptyitemtext = '(none)';
        this.noresultsfoundtext = 'No results found';
        this.enableadditem = true;
        this.additemcaption = 'New record';
        this.searchfieldplaceholder = 'Search';
        this.searchvalue = '';
        this.enabled = true;
        this.readonlyclass = '';
        this.container = null;
        this.selectedElement = null;
        this.searchfield = null;
        this._keyboardSearchPrefix = '';
        this._keyboardSearchLastKeystroke = null;
    }
    processKeydown(event) {
        if (event.key == 'Escape') {
            this.resetPrefixSearch();
            // escape key
            this.open = false;
            event.stopPropagation();
        }
        else if (event.key == 'Enter') {
            this.resetPrefixSearch();
            // enter key
            this.open = !this.open;
            event.stopPropagation();
            return false;
        }
        else if (event.key == 'ArrowDown') {
            this.resetPrefixSearch();
            event.stopPropagation();
            event.preventDefault();
            //down key
            var currentValues = ControlInfoValue.getAtomicValues_impl(this.getFilteredValues());
            if (currentValues.length > 0) {
                var pos = currentValues.findIndex(v => v.value.trim() == this.value.trim());
                if (pos == -1) {
                    this.setValueWithoutClosing(currentValues[0].value.trim(), false);
                }
                else {
                    pos = (((pos + 1) % currentValues.length) + currentValues.length) % currentValues.length;
                    this.setValueWithoutClosing(currentValues[pos].value.trim(), false);
                }
            }
        }
        else if (event.key == 'ArrowUp') {
            this.resetPrefixSearch();
            event.stopPropagation();
            event.preventDefault();
            //up key
            var currentValues = ControlInfoValue.getAtomicValues_impl(this.getFilteredValues());
            if (currentValues.length > 0) {
                var pos = currentValues.findIndex(v => v.value.trim() == this.value.trim());
                if (pos == -1) {
                    this.setValueWithoutClosing(currentValues[currentValues.length - 1].value.trim(), false);
                }
                else {
                    pos = (((pos - 1) % currentValues.length) + currentValues.length) % currentValues.length;
                    this.setValueWithoutClosing(currentValues[pos].value.trim(), false);
                }
            }
        }
        else {
            var key = event.key;
            // Check if the key pressed maps to a single character
            if (key.length == 1) {
                if (document.activeElement != this.searchfield) {
                    var currentDate = Date.now();
                    if (this._keyboardSearchLastKeystroke == null || currentDate - this._keyboardSearchLastKeystroke > 3000) {
                        this._keyboardSearchPrefix = '';
                    }
                    this._keyboardSearchPrefix = this._keyboardSearchPrefix + key;
                    var currentValues = ControlInfoValue.getAtomicValues_impl(this.getFilteredValues());
                    var selectedValue = currentValues.find(v => v.description.toLowerCase().indexOf(this._keyboardSearchPrefix.toLowerCase()) == 0);
                    if (selectedValue != null) {
                        this.setValueWithoutClosing(selectedValue.value.trim(), false);
                    }
                    this._keyboardSearchLastKeystroke = currentDate;
                }
            }
        }
    }
    onFocusIn() {
        this.resetPrefixSearch();
        this.focusEvent.emit();
    }
    resetPrefixSearch() {
        this._keyboardSearchLastKeystroke = null;
    }
    closeMenu(ev) {
        this.resetPrefixSearch();
        if (!this.container.contains(ev.target))
            this.open = false;
    }
    getHeaderContent() {
        if (this.value == null)
            return this.emptyitemtext;
        else
            var vals = this.getAtomicValues().filter(value => value.value.trim() == this.value.trim());
        if (vals.length > 0)
            return vals[0].description;
        else
            return this.emptyitemtext;
    }
    toggleContentVisibilty() {
        this.resetPrefixSearch();
        this.open = !this.open;
    }
    getRawValues() {
        var result;
        if (this.values == null) {
            result = [];
        }
        else if (typeof this.values === 'string') {
            if (this.values == '')
                result = [];
            else
                result = JSON.parse(this.values);
        }
        else {
            result = [...this.values];
        }
        if (this.includeemptyitem) {
            result.unshift({
                value: '',
                description: this.emptyitemtext,
                imageUrl: '',
                detail: '',
                trailingText: '',
                items: [],
            });
        }
        return result;
    }
    getFilteredValues() {
        var result = this.getRawValues();
        if (this.includesearch && this.searchvalue != '')
            result = this.getFilteredValues_impl(result);
        return result;
    }
    getFilteredValues_impl(origin) {
        var result = [];
        if (origin != undefined) {
            for (let cv of origin) {
                if (cv.description.toLocaleLowerCase().indexOf(this.searchvalue.toLocaleLowerCase()) != -1 ||
                    cv.detail.toLocaleLowerCase().indexOf(this.searchvalue.toLocaleLowerCase()) != -1 ||
                    cv.trailingText.toLocaleLowerCase().indexOf(this.searchvalue.toLocaleLowerCase()) != -1) {
                    result = result.concat(cv);
                }
                else {
                    // Check if child items must be added
                    var filteredChildren = this.getFilteredValues_impl(cv.items);
                    if (filteredChildren.length > 0) {
                        var cv2 = Object.assign({}, cv);
                        cv2.items = filteredChildren;
                        result = result.concat(cv2);
                    }
                }
            }
        }
        return result;
    }
    setValue(value) {
        this.setValueWithoutClosing(value, true);
        this.open = false;
    }
    setValueWithoutClosing(value, triggerChangeEventImmediately) {
        this.value = value;
        if (this.setValueDebouncer) {
            clearTimeout(this.setValueDebouncer);
            this.setValueDebouncer = null;
        }
        if (triggerChangeEventImmediately) {
            this.inputEvent.emit();
            this.changeEvent.emit(value);
        }
        else {
            this.setValueDebouncer = setTimeout((() => {
                this.setValueDebouncer = null;
                this.inputEvent.emit();
                this.changeEvent.emit(value);
            }).bind(this), 200);
        }
    }
    changeSearchValue(value) {
        this.searchvalue = value;
        this.searchChangedEvent.emit({ value });
    }
    onIncludeNewRecordClick() {
        this.open = false;
        this.newRecordClickedEvent.emit(null);
    }
    render() {
        this.selectedElement = null;
        return (h("div", null,
            h("p", { class: "form-control-static", style: this.enabled ? { display: 'none' } : {} },
                h("span", { class: this.readonlyclass }, this.getHeaderContent())),
            h("div", { tabindex: "0", class: "K2BTEnhancedCombo", ref: node => (this.container = node), style: !this.enabled ? { display: 'none' } : {} },
                h("div", { class: "K2BTEnhancedComboHeader", onClick: () => this.toggleContentVisibilty() }, this.getHeaderContent()),
                h("div", { class: this.open ? 'K2BTEnhancedComboContentsOpen' : 'K2BTEnhancedComboContentsClosed' },
                    this.includesearch ? (h("input", { type: "text", class: "K2BTEnhancedComboSearchInput", ref: c => (this.searchfield = c), onInput: event => {
                            this.changeSearchValue(event.target.value);
                            event.stopPropagation();
                        }, onChange: event => event.stopPropagation(), placeholder: this.searchfieldplaceholder })) : (''),
                    h("div", { class: "K2BTEnhancedComboItems" }, this.getComboContent()),
                    this.enableadditem ? (h("span", { class: "K2BTEnhancedComboNewAction", onClick: () => this.onIncludeNewRecordClick() }, this.additemcaption)) : ('')))));
    }
    getAtomicValues() {
        return ControlInfoValue.getAtomicValues_impl(this.getRawValues());
    }
    getComboContent() {
        const rawValues = ControlInfoValue.getAtomicValues_impl(this.getRawValues());
        var containsDetails = ControlInfoValue.containsDetails(rawValues);
        var containsIcons = ControlInfoValue.containsIcons(rawValues);
        var containsTrailingText = ControlInfoValue.containsTrailingText(rawValues);
        const filteredValues = !this.open ? [] : this.getFilteredValues();
        if (filteredValues.length > 0)
            return filteredValues.map(item => this.getItemContent(item, containsDetails, containsIcons, containsTrailingText));
        else
            return h("div", { class: "K2BTEnhancedComboNoItemsFound" }, this.noresultsfoundtext);
    }
    onImageError(e) {
        e.target.classList.add('K2BTEnhancedComboIconInvisible');
    }
    getItemContent(item, containsDetails, containsIcons, containsTrailingText) {
        var _a;
        if (((_a = item.items) === null || _a === void 0 ? void 0 : _a.length) > 0) {
            // Item is a category
            return (h("div", { class: "K2BTEnhancedComboCategory" },
                h("span", { class: "K2BTEnhancedComboCategoryName" }, item.description),
                h("div", { class: "K2BTEnchancedComboCategoryContents" }, item.items.map(item => this.getItemContent(item, containsDetails, containsIcons, containsTrailingText)))));
        }
        else {
            return (h("div", { class: this.value.trim() == item.value.trim() ? 'K2BTEnhancedComboItem K2BTEnhancedComboSelected' : 'K2BTEnhancedComboItem', ref: c => {
                    if (this.value.trim() == item.value.trim())
                        this.selectedElement = c;
                }, onClick: () => this.setValue(item.value.trim()) },
                containsIcons ? (h("div", { class: "K2BTEnhancedComboIconContainer" },
                    h("img", { class: "K2BTEnhancedComboIcon", src: item.imageUrl, onError: e => this.onImageError(e) }))) : (''),
                h("div", { class: "K2BTEnhancedComboItem_TextColumn" },
                    h("div", { class: "K2BTEnhancedComboItem_TextContainer" },
                        h("span", { class: "K2BTEnhancedComboDescription" }, this.getHighlightedText(item.description)),
                        containsTrailingText ? h("span", { class: "K2BTEnhancedComboTrailingText" }, this.getHighlightedText(item.trailingText)) : ''),
                    h("div", { class: "K2BTEnhancedComboItem_TextContainer" }, containsDetails ? h("span", { class: "K2BTEnhancedComboSubtitle" }, this.getHighlightedText(item.detail)) : ''))));
        }
    }
    getHighlightedText(originalText) {
        var position = originalText.toLowerCase().indexOf(this.searchvalue.toLowerCase());
        if (this.searchvalue == undefined || this.searchvalue == '' || position == -1) {
            return h("span", null, originalText);
        }
        else {
            return (h("span", null,
                originalText.substring(0, position),
                h("span", { class: "K2BTEnhancedComboSearchHighlight" }, originalText.substring(position, position + this.searchvalue.length)),
                this.getHighlightedText(originalText.substring(position + this.searchvalue.length))));
        }
    }
    componentDidRender() {
        if (this.selectedElement != null) {
            this.selectedElement.scrollIntoView({ block: 'nearest' });
        }
    }
    componentDidLoad() {
        var currentValues = this.getAtomicValues();
        if (!this.includeemptyitem && currentValues.filter(v => v.value.trim() == this.value.trim()).length == 0) {
            if (currentValues.length > 0) {
                this.setValueWithoutClosing(currentValues[0].value.trim(), true);
            }
        }
    }
    static get is() { return "k2bt-enhancedcombo"; }
    static get originalStyleUrls() { return {
        "$": ["k2bt-enhancedcombo.css"]
    }; }
    static get styleUrls() { return {
        "$": ["k2bt-enhancedcombo.css"]
    }; }
    static get properties() { return {
        "value": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "value",
            "reflect": false,
            "defaultValue": "null"
        },
        "values": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "Array<object> | string",
                "resolved": "object[] | string",
                "references": {
                    "Array": {
                        "location": "global"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "values",
            "reflect": false
        },
        "includesearch": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "includesearch",
            "reflect": false,
            "defaultValue": "true"
        },
        "includeemptyitem": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "includeemptyitem",
            "reflect": false,
            "defaultValue": "true"
        },
        "emptyitemtext": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "emptyitemtext",
            "reflect": false,
            "defaultValue": "'(none)'"
        },
        "noresultsfoundtext": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "noresultsfoundtext",
            "reflect": false,
            "defaultValue": "'No results found'"
        },
        "open": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "open",
            "reflect": false
        },
        "enableadditem": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "enableadditem",
            "reflect": false,
            "defaultValue": "true"
        },
        "additemcaption": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "additemcaption",
            "reflect": false,
            "defaultValue": "'New record'"
        },
        "searchfieldplaceholder": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "searchfieldplaceholder",
            "reflect": false,
            "defaultValue": "'Search'"
        },
        "searchvalue": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "searchvalue",
            "reflect": false,
            "defaultValue": "''"
        },
        "enabled": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "enabled",
            "reflect": false,
            "defaultValue": "true"
        },
        "readonlyclass": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "readonlyclass",
            "reflect": false,
            "defaultValue": "''"
        }
    }; }
    static get events() { return [{
            "method": "focusEvent",
            "name": "focus",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "complexType": {
                "original": "object",
                "resolved": "object",
                "references": {}
            }
        }, {
            "method": "inputEvent",
            "name": "input",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "complexType": {
                "original": "object",
                "resolved": "object",
                "references": {}
            }
        }, {
            "method": "changeEvent",
            "name": "change",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "complexType": {
                "original": "object",
                "resolved": "object",
                "references": {}
            }
        }, {
            "method": "searchChangedEvent",
            "name": "searchChanged",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "complexType": {
                "original": "object",
                "resolved": "object",
                "references": {}
            }
        }, {
            "method": "newRecordClickedEvent",
            "name": "newRecordClicked",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": ""
            },
            "complexType": {
                "original": "object",
                "resolved": "object",
                "references": {}
            }
        }]; }
    static get listeners() { return [{
            "name": "keydown",
            "method": "processKeydown",
            "target": undefined,
            "capture": false,
            "passive": false
        }, {
            "name": "focusin",
            "method": "onFocusIn",
            "target": undefined,
            "capture": false,
            "passive": false
        }, {
            "name": "click",
            "method": "closeMenu",
            "target": "window",
            "capture": false,
            "passive": false
        }]; }
}
